<a href="https://pypi.org/project/esbmtk/">
<img alt="Documentation Status" src="https://img.shields.io/pypi/v/esbmtk.svg"/>
</a>

<a href="https://pyscaffold.org">
<img alt="Project generated with PyScaffold" src="https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold"/>
</a>

<a href="https://esbmtk.readthedocs.io/en/latest/?badge=latest">
<img alt="Documentation Status" src="https://readthedocs.org/projects/esbmtk/badge/?version=latest" />
</a>


# ESBMTK - The  Earth Sciences Box Modeling Toolkit

ESBMTK is a python library that aims to simplify typical box modeling
projects in the Earth-Sciences. The basic API is now stable, but the code to deploy complex models is still being improved. See the manual at <https://esbmtk.readthedocs.io/en/latest> for installation instructions and usage.

